==> rocalution-5.6.0-1-x86_64.pkg.tar.zst: opt/rocm/lib/cmake/rocalution/rocalution-targets-none.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "None".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "roc::rocalution" for configuration "None"
set_property(TARGET roc::rocalution APPEND PROPERTY IMPORTED_CONFIGURATIONS NONE)
set_target_properties(roc::rocalution PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_NONE "roc::rocalution_hip"
  IMPORTED_LOCATION_NONE "${_IMPORT_PREFIX}/lib/librocalution.so.0.1"
  IMPORTED_SONAME_NONE "librocalution.so.0"
  )

list(APPEND _cmake_import_check_targets roc::rocalution )
list(APPEND _cmake_import_check_files_for_roc::rocalution "${_IMPORT_PREFIX}/lib/librocalution.so.0.1" )

# Import target "roc::rocalution_hip" for configuration "None"
set_property(TARGET roc::rocalution_hip APPEND PROPERTY IMPORTED_CONFIGURATIONS NONE)
set_target_properties(roc::rocalution_hip PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_NONE "roc::rocblas;roc::rocsparse;roc::rocrand"
  IMPORTED_LOCATION_NONE "${_IMPORT_PREFIX}/lib/librocalution_hip.so.0.1"
  IMPORTED_SONAME_NONE "librocalution_hip.so.0"
  )

list(APPEND _cmake_import_check_targets roc::rocalution_hip )
list(APPEND _cmake_import_check_files_for_roc::rocalution_hip "${_IMPORT_PREFIX}/lib/librocalution_hip.so.0.1" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)

==> rocalution-7.1.1-1-x86_64.pkg.tar.zst: opt/rocm/lib/cmake/rocalution/rocalution-targets-none.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "None".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "roc::rocalution" for configuration "None"
set_property(TARGET roc::rocalution APPEND PROPERTY IMPORTED_CONFIGURATIONS NONE)
set_target_properties(roc::rocalution PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_NONE "roc::rocalution_hip"
  IMPORTED_LOCATION_NONE "${_IMPORT_PREFIX}/lib/librocalution.so.1.0"
  IMPORTED_SONAME_NONE "librocalution.so.1"
  )

list(APPEND _cmake_import_check_targets roc::rocalution )
list(APPEND _cmake_import_check_files_for_roc::rocalution "${_IMPORT_PREFIX}/lib/librocalution.so.1.0" )

# Import target "roc::rocalution_hip" for configuration "None"
set_property(TARGET roc::rocalution_hip APPEND PROPERTY IMPORTED_CONFIGURATIONS NONE)
set_target_properties(roc::rocalution_hip PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_NONE "roc::rocblas;roc::rocsparse;roc::rocrand"
  IMPORTED_LOCATION_NONE "${_IMPORT_PREFIX}/lib/librocalution_hip.so.1.0.0"
  IMPORTED_SONAME_NONE "librocalution_hip.so.1"
  )

list(APPEND _cmake_import_check_targets roc::rocalution_hip )
list(APPEND _cmake_import_check_files_for_roc::rocalution_hip "${_IMPORT_PREFIX}/lib/librocalution_hip.so.1.0.0" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)
